@@ -8,7 +8,7 @@ import sass
 
 from .launch import update_thebelab_context, init_thebelab_core, add_hub_urls
 
-__version__ = "0.0.19"
+__version__ = "0.0.20"
 SPHINX_LOGGER = logging.getLogger(__name__)
 
 
@@ -194,7 +194,7 @@ def add_to_context(app, pagename, templatename, context, doctree):
         repo_url = config_theme.get("repository_url", "")
         # Only add the edit button if `repository_url` is given
         if repo_url:
-            branch = config_theme.get("repository_branch", "")
+            branch = config_theme.get("repository_branch", "master")
             relpath = config_theme.get("path_to_docs", "")
             org, repo = repo_url.strip("/").split("/")[-2:]
             context.update(
